@@ -60,17 +60,17 @@ def get_contamination_metrics(largest_contigs_indexes, bam_file, cont_names, par
             if not read.is_unmapped: ##read.tid == read.rnext and not read.mate_is_unmapped and not read.is_unmapped: #
                 counter_total += 1
 
-        # contamination reads (mapped in reverse complemented orientation)
-        if  param.orientation == 'fr' and bam_parser.is_proper_aligned_unique_outie(read):
-            if read.rname in largest_contigs_indexes:
-                contamination_reads.append(abs(read.tlen)+2*param.read_len)
-                count_contamine += 2
-        if  param.orientation == 'rf' and bam_parser.is_proper_aligned_unique_innie(read):
-            if read.rname in largest_contigs_indexes:
-                contamination_reads.append(abs(read.tlen))
-                count_contamine += 2 
-        if counter >= iter_threshold:
-                break
+            # contamination reads (mapped in reverse complemented orientation)
+            if  param.orientation == 'fr' and bam_parser.is_proper_aligned_unique_outie(read):
+                if read.rname in largest_contigs_indexes:
+                    contamination_reads.append(abs(read.tlen)+2*param.read_len)
+                    count_contamine += 2
+            if  param.orientation == 'rf' and bam_parser.is_proper_aligned_unique_innie(read):
+                if read.rname in largest_contigs_indexes:
+                    contamination_reads.append(abs(read.tlen))
+                    count_contamine += 2 
+            if counter >= iter_threshold:
+                    break
 
     ## SMOOTH OUT contamine distribution here by removing extreme observations## 
     n_contamine = float(len(contamination_reads))
@@ -104,7 +104,7 @@ def get_contamination_metrics(largest_contigs_indexes, bam_file, cont_names, par
     else:
         param.contamination_mean = mean_isize
         param.contamination_stddev = std_dev_isize
-        param.contamination_ratio = count_contamine / float(counter_total)
+        param.contamination_ratio = 2*n_contamine / float(counter_total)
 
     bam_file.reset()
     return n_contamine
